Data documentation compiled by Great Expectations

### Validation Overview

#### Info

Full Data Asset Identifier | titanic/default/Titanic
Expectation Suite Name | BasicDatasetProfiler
Great Expectations Version | 0.8.0a3+87.g25671d3a.dirty
Run ID | test_run_id_12345
Validation Succeeded | False

#### Statistics

Evaluated Expectations | 51
Successful Expectations | 43
Unsuccessful Expectations | 8
Success Percent | 84.31%

### Unnamed: 0

Status | Expectation | Observed Value
--- | --- | ---
| value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int. | int64
| may have any number of unique values. | 1313
| may have any percentage of unique values. | 1.0
| values must not be null, at least 50.0 % of the time. | 100.0000% not null
| values must belong to this set: [ ]. 1313 unexpected values found. 100.00% of 1313 total rows.
Unexpected Value
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
| 100.0000% unexpected
| values must be unique. | 0.0000% unexpected

### Name

Status | Expectation | Observed Value
--- | --- | ---
| value types must belong to this set: CHAR StringType TEXT VARCHAR str string. | 0.0000% unexpected
| may have any number of unique values. | 1310
| may have any percentage of unique values. | 0.9977151561309977
| values must not be null, at least 50.0 % of the time. | 100.0000% not null
| values must belong to this set: [ ]. 1313 unexpected values found. 100.00% of 1313 total rows.
Unexpected Value
Allen, Miss Elisabeth Walton
Allison, Miss Helen Loraine
Allison, Mr Hudson Joshua Creighton
Allison, Mrs Hudson JC (Bessie Waldo Daniels)
Allison, Master Hudson Trevor
Anderson, Mr Harry
Andrews, Miss Kornelia Theodosia
Andrews, Mr Thomas, jr
Appleton, Mrs Edward Dale (Charlotte Lamson)
Artagaveytia, Mr Ramon
Astor, Colonel John Jacob
Astor, Mrs John Jacob (Madeleine Talmadge Force)
Aubert, Mrs Leontine Pauline
Barkworth, Mr Algernon H
Baumann, Mr John D
Baxter, Mrs James (Helene DeLaudeniere Chaput)
Baxter, Mr Quigg Edmond
Beattie, Mr Thomson
Beckwith, Mr Richard Leonard
Beckwith, Mrs Richard Leonard (Sallie Monypeny)
| 100.0000% unexpected
| values must not match this regular expression: ^\s+|\s+$. 3 unexpected values found. 0.23% of 1313 total rows.
Unexpected Value
Daly, Mr Peter Denis
Barber, Ms
Geiger, Miss Emily
| 0.2285% unexpected

### PClass

Status | Expectation | Observed Value
--- | --- | ---
| value types must belong to this set: CHAR StringType TEXT VARCHAR str string. | 0.0000% unexpected
| may have any number of unique values. | 4
| may have any percentage of unique values. | 0.0030464584920030465
| values must not be null, at least 50.0 % of the time. | 100.0000% not null
| values must belong to this set: [ ]. 1313 unexpected values found. 100.00% of 1313 total rows.
Unexpected Value
1st
1st
1st
1st
1st
1st
1st
1st
1st
1st
1st
1st
1st
1st
1st
1st
1st
1st
1st
1st
| 100.0000% unexpected
| values must not match this regular expression: ^\s+|\s+$. | 0.0000% unexpected
| distinct values must belong to a set, but that set is not specified. | ['*', '1st', '2nd', '3rd']

### Age

Status | Expectation | Observed Value
--- | --- | ---
| value types must belong to this set: DOUBLE_PRECISION DoubleType FLOAT FLOAT4 FLOAT8 FloatType NUMERIC float. | float64
| may have any number of unique values. | 75
| may have any percentage of unique values. | 0.0992063492063492
| values must not be null, at least 50.0 % of the time. | 57.5781% not null
| values must belong to this set: [ ]. 756 unexpected values found. 57.58% of 1313 total rows.
Unexpected Value
29.0
2.0
30.0
25.0
0.92
47.0
63.0
39.0
58.0
71.0
47.0
19.0
50.0
24.0
36.0
37.0
47.0
26.0
25.0
25.0
| 57.5781% unexpected
| minimum value may have any numerical value. | 0.17
| maximum value may have any numerical value. | 71.0
| mean may have any numerical value. | 30.397989417989418
| median may have any numerical value. | 28.0
| expect_column_quantile_values_to_be_between(**{'column': 'Age', 'quantile_ranges': {'quantiles': [0.05, 0.25, 0.5, 0.75, 0.95], 'value_ranges': [[None, None], [None, None], [None, None], [None, None], [None, None]]}}) | {'quantiles': [0.05, 0.25, 0.5, 0.75, 0.95], 'values': [6.0, 21.0, 28.0, 39.0, 57.0]}
| Kullback-Leibler (KL) divergence with respect to a given distribution must be lower than a provided threshold but no distribution was specified. | --

### Sex

Status | Expectation | Observed Value
--- | --- | ---
| value types must belong to this set: CHAR StringType TEXT VARCHAR str string. | 0.0000% unexpected
| may have any number of unique values. | 2
| may have any percentage of unique values. | 0.0015232292460015233
| values must not be null, at least 50.0 % of the time. | 100.0000% not null
| values must belong to this set: [ ]. 1313 unexpected values found. 100.00% of 1313 total rows.
Unexpected Value
female
female
male
female
male
male
female
male
female
male
male
female
female
male
male
female
male
male
male
female
| 100.0000% unexpected
| values must not match this regular expression: ^\s+|\s+$. | 0.0000% unexpected
| distinct values must belong to a set, but that set is not specified. | ['female', 'male']

### Survived

Status | Expectation | Observed Value
--- | --- | ---
| value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int. | int64
| may have any number of unique values. | 2
| may have any percentage of unique values. | 0.0015232292460015233
| values must not be null, at least 50.0 % of the time. | 100.0000% not null
| values must belong to this set: [ ]. 1313 unexpected values found. 100.00% of 1313 total rows.
Unexpected Value
1
null
null
null
1
1
1
null
1
null
null
1
1
1
null
1
null
null
1
1
| 100.0000% unexpected
| distinct values must belong to a set, but that set is not specified. | [0, 1]

### SexCode

Status | Expectation | Observed Value
--- | --- | ---
| value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int. | int64
| may have any number of unique values. | 2
| may have any percentage of unique values. | 0.0015232292460015233
| values must not be null, at least 50.0 % of the time. | 100.0000% not null
| values must belong to this set: [ ]. 1313 unexpected values found. 100.00% of 1313 total rows.
Unexpected Value
1
1
null
1
null
null
1
null
1
null
null
1
1
null
null
1
null
null
null
1
| 100.0000% unexpected
| distinct values must belong to a set, but that set is not specified. | [0, 1]

Documentation autogenerated using Great Expectations.

This is a beta feature! Expect changes in API, behavior, and design.

Documentation autogenerated using Great Expectations.

This is a beta feature! Expect changes in API, behavior, and design.